@@ -10,6 +10,7 @@
 
 #include "net.h"
 #include "i18n.h"
+#include <ggz.h>
 #include <ggzcore.h>
 #include <stdlib.h>
 #include <string.h>
@@ -102,28 +103,28 @@ static void net_internal_queueadd(const char *player, const char *message, int t
 	}
 
 	/* Insert new grubby structure */
-	guru = (Guru*)malloc(sizeof(Guru));
+	guru = (Guru*)ggz_malloc(sizeof(Guru));
 	guru->type = type;
-	if(player) guru->player = strdup(player);
+	if(player) guru->player = ggz_strdup(player);
 	else guru->player = NULL;
 	guru->playertype = playertype;
 	if(message)
 	{
-		guru->message = strdup(message);
+		guru->message = ggz_strdup(message);
 		guru->list = NULL;
-		listtoken = strdup(message);
+		listtoken = ggz_strdup(message);
 		token = strtok(listtoken, " ,./:?!\'");
 		i = 0;
 		while(token)
 		{
-			guru->list = (char**)realloc(guru->list, (i + 2) * sizeof(char*));
-			guru->list[i] = (char*)malloc(strlen(token) + 1);
+			guru->list = (char**)ggz_realloc(guru->list, (i + 2) * sizeof(char*));
+			guru->list[i] = (char*)ggz_malloc(strlen(token) + 1);
 			strcpy(guru->list[i], token);
 			guru->list[i + 1] = NULL;
 			i++;
 			token = strtok(NULL, " ,./:?!\'");
 		}
-		free(listtoken);
+		ggz_free(listtoken);
 	}
 	else
 	{
@@ -138,11 +139,19 @@ static void net_internal_queueadd(const char *player, const char *message, int t
 
 	/* Insert structure into queue */
 	queuelen++;
-	queue = (Guru**)realloc(queue, sizeof(Guru*) * queuelen);
+	queue = (Guru**)ggz_realloc(queue, sizeof(Guru*) * queuelen);
 	queue[queuelen - 2] = guru;
 	queue[queuelen - 1] = NULL;
 }
 
+void net_cleanup()
+{
+	ggzcore_server_logout(server);
+	ggzcore_server_disconnect(server);
+	ggzcore_server_free(server);
+	ggzcore_destroy();
+}
+
 /* Transparently connect to any host */
 void net_connect(const char *host, int port, const char *name, const char *password)
 {
@@ -189,8 +198,12 @@ void net_join(const char *room)
 		}
 	}
 
-	if(room) ggzcore_server_join_room(server, roomid);
-	else ggzcore_server_join_room(server, 0);
+	if(room)
+	{
+		ggzroom = ggzcore_server_get_nth_room(server, roomid);
+		ggzcore_server_join_room(server, ggzroom);
+	}
+	else ggzcore_server_join_room(server, NULL);
 }
 
 /* Loop function */
@@ -289,7 +302,7 @@ void net_output(Guru *output)
 	if(!output->message) return;
 /*printf("DEBUG: output is at %i\n", output);
 printf("DEBUG: net_output(%s)\n", output->message);*/
-	msg = strdup(output->message);
+	msg = ggz_strdup(output->message);
 	token = strtok(msg, "\n");
 	while(token)
 	{
@@ -312,7 +325,7 @@ printf("DEBUG: net_output(%s)\n", output->message);*/
 		}
 		token = strtok(NULL, "\n");
 	}
-	free(msg);
+	ggz_free(msg);
 }
 
 /* Callback for successful connection */
@@ -500,6 +513,33 @@ void net_internal_gameprepare(const char *playername)
 	}
 }
 
+int net_get_playertype(const char *playername)
+{
+	int playertype;
+	int i;
+	int players;
+	GGZPlayer *player;
+	GGZPlayerType tmp;
+
+	playertype = PLAYER_UNKNOWN;
+	players = ggzcore_room_get_num_players(room);
+	for(i = 0; i < players; i++)
+	{
+		player = ggzcore_room_get_nth_player(room, i);
+		if(!strcmp(ggzcore_player_get_name(player), playername))
+		{
+			tmp = ggzcore_player_get_type(player);
+			if(tmp == GGZ_PLAYER_GUEST) playertype = PLAYER_GUEST;
+			if(tmp == GGZ_PLAYER_NORMAL) playertype = PLAYER_REGISTERED;
+			if(tmp == GGZ_PLAYER_HOST) playertype = PLAYER_HOST;
+			if(tmp == GGZ_PLAYER_ADMIN) playertype = PLAYER_ADMIN;
+			break;
+		}
+	}
+
+	return playertype;
+}
+
 /* Chat callback which passes message to grubby */
 GGZHookReturn net_hook_chat(unsigned int id, const void *event_data, const void *user_data)
 {
@@ -508,27 +548,14 @@ GGZHookReturn net_hook_chat(unsigned int id, const void *event_data, const void
 	time_t t;
 	char *ts;
 	int playertype;
-	int players, i, tmp;
-	GGZPlayer *player;
+	/*int players, i, tmp;
+	GGZPlayer *player;*/
 	const GGZChatEventData *chat = event_data;
 
 	/* Ignore all self-generates messages */
 	if (strcmp(chat->sender, guruname))
 	{
-		playertype = PLAYER_UNKNOWN;
-		players = ggzcore_room_get_num_players(room);
-		for(i = 0; i < players; i++)
-		{
-			player = ggzcore_room_get_nth_player(room, i);
-			if(!strcmp(ggzcore_player_get_name(player), chat->sender))
-			{
-				tmp = ggzcore_player_get_type(player);
-				if(tmp == GGZ_PLAYER_GUEST) playertype = PLAYER_GUEST;
-				if(tmp == GGZ_PLAYER_NORMAL) playertype = PLAYER_REGISTERED;
-				if(tmp == GGZ_PLAYER_ADMIN) playertype = PLAYER_ADMIN;
-				break;
-			}
-		}
+		playertype = net_get_playertype(chat->sender);
 
 		if (chat->type == GGZ_CHAT_PERSONAL) type = GURU_PRIVMSG;
 		else type = GURU_CHAT;
