@@ -23,12 +23,15 @@ enum States
 };
 
 /* Interface */
+void net_cleanup(void);
 void net_connect(const char *host, int port, const char *name, const char *password);
 void net_join(const char *room);
 int net_status(void);
 Guru *net_input(void);
 void net_output(Guru *output);
 void net_logfile(const char *logfile);
+int net_get_playertype(const char *playername);
+
 
 #endif
 
